@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+from contextlib import contextmanager
 from textwrap import wrap
-from threading import Thread
+from threading import Event, Thread, Timer
 
 import click
 import click_spinner
@@ -16,19 +17,38 @@ MSG_UNABLE_TO_COMMUNICATE_WITH_CLIENT = (
 )
 
 
-def get_docker_client(timeout=10):
+@contextmanager
+def spinner(msg=None, final=None, delay=0):
+    """Display spinner only after an optional initial delay."""
+
+    def spin():
+        if msg:
+            click.echo(f"{msg.rstrip()} ", nl=False, err=True)
+        with click_spinner.spinner():
+            stop.wait()
+        if completed.is_set() and msg:
+            click.echo(final or "done.", err=True)
+
+    stop = Event()
+    completed = Event()
+    timed_spinner = Timer(delay, spin)
+    timed_spinner.start()
     try:
-        try:
-            # Make first attempt with very short timeout.
-            return docker.from_env(timeout=1)
-        except docker.errors.DockerException as error:
-            if "ConnectTimeoutError" in str(error):
-                # Second attempt with longer timeout and user indication.
-                click.echo("Connecting to docker host...", err=True)
-                with click_spinner.spinner():
-                    return docker.from_env(timeout=timeout)
-            else:
-                raise  # unrelated error, escalate immediately
+        yield
+        # Try to cancel the timer if still possible.
+        timed_spinner.cancel()
+        # Set the completed event since there was no exception, indicating that
+        # the waited on operation completed successfully.
+        completed.set()
+    finally:
+        stop.set()
+        timed_spinner.join()
+
+
+def get_docker_client(*args, **kwargs):
+    try:
+        with spinner("Connecting to docker host...", delay=0.2):
+            return docker.from_env(*args, **kwargs)
     except docker.errors.DockerException as error:
         click.secho(
             "\n".join(wrap(MSG_UNABLE_TO_COMMUNICATE_WITH_CLIENT)),
